==> ns3_3.37.orig.tar.bz2: ns-allinone-3.37/ns-3.37/src/internet-apps/helper/v4ping-helper.cc <==
/*
 * Copyright (c) 2008 INRIA
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Mathieu Lacage <mathieu.lacage@sophia.inria.fr>
 */

#include "v4ping-helper.h"

#include "ns3/names.h"
#include "ns3/v4ping.h"

namespace ns3
{

V4PingHelper::V4PingHelper(Ipv4Address remote)
{
    m_factory.SetTypeId("ns3::V4Ping");
    m_factory.Set("Remote", Ipv4AddressValue(remote));
}

void
V4PingHelper::SetAttribute(std::string name, const AttributeValue& value)
{
    m_factory.Set(name, value);
}

ApplicationContainer
V4PingHelper::Install(Ptr<Node> node) const
{
    return ApplicationContainer(InstallPriv(node));
}

ApplicationContainer
V4PingHelper::Install(std::string nodeName) const
{
    Ptr<Node> node = Names::Find<Node>(nodeName);
    return ApplicationContainer(InstallPriv(node));
}

ApplicationContainer
V4PingHelper::Install(NodeContainer c) const
{
    ApplicationContainer apps;
    for (NodeContainer::Iterator i = c.Begin(); i != c.End(); ++i)
    {
        apps.Add(InstallPriv(*i));
    }

    return apps;
}

Ptr<Application>
V4PingHelper::InstallPriv(Ptr<Node> node) const
{
    Ptr<V4Ping> app = m_factory.Create<V4Ping>();
    node->AddApplication(app);

    return app;
}

} // namespace ns3

==> ns3_3.39.orig.tar.bz2: ns-allinone-3.39/ns-3.39/src/internet-apps/helper/v4ping-helper.cc <==
/*
 * Copyright (c) 2008 INRIA
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Mathieu Lacage <mathieu.lacage@sophia.inria.fr>
 */

#include "v4ping-helper.h"

#include "ns3/names.h"
#include "ns3/v4ping.h"
#include "ns3/warnings.h"

namespace ns3
{

V4PingHelper::V4PingHelper(Ipv4Address remote)
{
    NS_WARNING_PUSH_DEPRECATED;
    m_factory.SetTypeId("ns3::V4Ping");
    m_factory.Set("Remote", Ipv4AddressValue(remote));
    NS_WARNING_POP;
}

void
V4PingHelper::SetAttribute(std::string name, const AttributeValue& value)
{
    m_factory.Set(name, value);
}

ApplicationContainer
V4PingHelper::Install(Ptr<Node> node) const
{
    return ApplicationContainer(InstallPriv(node));
}

ApplicationContainer
V4PingHelper::Install(std::string nodeName) const
{
    Ptr<Node> node = Names::Find<Node>(nodeName);
    return ApplicationContainer(InstallPriv(node));
}

ApplicationContainer
V4PingHelper::Install(NodeContainer c) const
{
    ApplicationContainer apps;
    for (NodeContainer::Iterator i = c.Begin(); i != c.End(); ++i)
    {
        apps.Add(InstallPriv(*i));
    }

    return apps;
}

Ptr<Application>
V4PingHelper::InstallPriv(Ptr<Node> node) const
{
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wdeprecated-declarations"

    Ptr<V4Ping> app = m_factory.Create<V4Ping>();
    node->AddApplication(app);

    return app;

#pragma GCC diagnostic pop
}

} // namespace ns3
